using ImageProcessingGraph.Editor.Nodes.NodeAttributes;


namespace ImageProcessingGraph.Editor.Nodes.String_Nodes
{
    [NodeInfo("String Append", "String/Append", docuementationURL: "https://git.sam-green.dev/Chromum/UnityImageProcessing_Package/wiki/Nodes/String/Append")]
    public class StringAppend : BaseImageNode
    {
        [NodeAttributes.Input("String A")] public string baseString;
        [NodeAttributes.Input("String B")] public string appendString;
        
        [NodeAttributes.Output("Appended String")] public string output;
        
        public override void Process()
        {
            this.output = baseString + appendString;
        }
    }
    
    [NodeInfo("String Replace", "String/Replace", docuementationURL: "https://git.sam-green.dev/Chromum/UnityImageProcessing_Package/wiki/Nodes/String/Replace")]
    public class StringReplace : BaseImageNode
    {
        [NodeAttributes.Input("Original String")] public string original;
        [NodeAttributes.Input("Old Value")] public string oldValue;
        [NodeAttributes.Input("New Value")] public string newValue;

        [NodeAttributes.Output("Replaced String")] public string output;

        public override void Process()
        {
            if (!string.IsNullOrEmpty(original) && oldValue != null)
                output = original.Replace(oldValue, newValue);
            else
                output = original;
        }
    }
    
    [NodeInfo("String Split", "String/Split", docuementationURL: "https://git.sam-green.dev/Chromum/UnityImageProcessing_Package/wiki/Nodes/String/Split")]
    public class StringSplit : BaseImageNode
    {
        [Input("Source String")] public string source;
        [Input("Delimiter")] public string delimiter;

        [NodeAttributes.Output("Before Delimiter")] public string before;
        [NodeAttributes.Output("After Delimiter")] public string after;

        public override void Process()
        {
            if (string.IsNullOrEmpty(source) || string.IsNullOrEmpty(delimiter))
            {
                before = source;
                after = string.Empty;
                return;
            }

            int index = source.IndexOf(delimiter);
            if (index >= 0)
            {
                before = source.Substring(0, index);
                after = source.Substring(index + delimiter.Length);
            }
            else
            {
                before = source;
                after = string.Empty;
            }
        }
    }
}