using UnityEditor;
using UnityEditor.PackageManager.UI;
using UnityEngine;
using UnityEngine.UIElements;

public class GettingStartedWindow : EditorWindow
{
    private static Vector2 WindowSize = new Vector2(400, 600);
    
    
    [MenuItem("Image Graph/Getting Started")]
    public static void ShowExample()
    {
        GettingStartedWindow wnd = GetWindow<GettingStartedWindow>();
        wnd.titleContent = new GUIContent("Getting Started Window");
        wnd.minSize = WindowSize;
        wnd.maxSize = WindowSize;
    }

    public void CreateGUI()
    {
        Foldout foldoutCreateGraph = new Foldout();
        {
            foldoutCreateGraph.name = "CreateGraph";
            foldoutCreateGraph.text = "Creating a Graph";
            AddBulletLabel(foldoutCreateGraph, "CreateGraphLabel", "Right click in project view");
            AddBulletLabel(foldoutCreateGraph, "PathLabel", "Create->Image Processing Graph->New Graph");
            AddBulletLabel(foldoutCreateGraph, "NameAsset", "Name Asset as Desired");
        }
        foldoutCreateGraph.value = false;
        rootVisualElement.Add(foldoutCreateGraph);
        
        Foldout foldoutOpenGraph = new Foldout();
        {
            foldoutOpenGraph.name = "OpenGraph";
            foldoutOpenGraph.text = "Opening a Graph";
            AddBulletLabel(foldoutOpenGraph, "DoubleClick", "Double click newly created asset or pre-existing asset");
            AddBulletLabel(foldoutOpenGraph, "Inspector", "With a graph asset selected click the \"Open\" button");
        }
        foldoutOpenGraph.value = false;
        rootVisualElement.Add(foldoutOpenGraph);
        
        Foldout foldoutUsingTheGraph = new Foldout();
        {
            foldoutUsingTheGraph.name = "Using the Graph";
            foldoutUsingTheGraph.text = "Using the Graph";
            
            Foldout foldoutCreatingNodes = new Foldout();
            {
                foldoutCreatingNodes.name = "Creating Nodes";
                foldoutCreatingNodes.text = "Creating Nodes";
                
                AddBulletLabel(foldoutCreatingNodes, "HowToOpenSearch", "To open the node creation window press the \"Space\" button or Right Click -> Create Node");
                AddBulletLabel(foldoutCreatingNodes, "Search Window", "With the Search window now open find the node you wish to create and press the \"Enter\" key; Or double left click");
                AddBulletLabel(foldoutCreatingNodes, "Arrow Keys", "The search window can also be controlled with the arrow keys!");
            }
            foldoutCreatingNodes.value = false;
            foldoutUsingTheGraph.Add(foldoutCreatingNodes);
            
            Foldout foldoutDeletingNodes = new Foldout();
            {
                foldoutDeletingNodes.name = "Deleting Nodes";
                foldoutDeletingNodes.text = "Deleting Nodes";

                AddBulletLabel(foldoutDeletingNodes, "Deleting Nodes", "To delete a node, you can click the \"Delete\" Key or Right Click -> Delete Node");
            }
            foldoutDeletingNodes.value = false;
            foldoutUsingTheGraph.Add(foldoutDeletingNodes);
            
            Foldout foldoutConnectingNodes = new Foldout();
            {
                foldoutConnectingNodes.name = "Connecting Nodes";
                foldoutConnectingNodes.text = "Connecting Nodes";
                
                AddBulletLabel(foldoutConnectingNodes, "ConnectingNodes", "To connect two nodes you click and drag from one port to the other (Ports must be of same type)");
                AddBulletLabel(foldoutConnectingNodes, "ConnectingNodesTooltip", "Hovering over a port will show its type", 1);
                AddBulletLabel(foldoutConnectingNodes, "DroppingConnection", "Dropping a connection in empty space will open a contextual search window");
                AddBulletLabel(foldoutConnectingNodes, "DroppingConnection1", "This window will only show nodes that are able to input/output to the port you dragged from.", 1);
            }
            foldoutConnectingNodes.value = false;
            foldoutUsingTheGraph.Add(foldoutConnectingNodes);
            
            Foldout foldoutDeletingConnections = new Foldout();
            {
                foldoutDeletingNodes.name = "Deleting Nodes";
                foldoutDeletingNodes.text = "Deleting Nodes";

                AddBulletLabel(foldoutDeletingNodes, "Deleting Nodes", "To delete a node, you can click the \"Delete\" Key or Right Click -> Delete Node");
            }
            foldoutDeletingNodes.value = false;
            foldoutUsingTheGraph.Add(foldoutDeletingNodes);
        }
        foldoutUsingTheGraph.value = false;
        rootVisualElement.Add(foldoutUsingTheGraph);

        Label bottomLabel = new Label("For more details, check the Quick Start Guide:");
        bottomLabel.style.marginTop = 20;
        bottomLabel.style.unityFontStyleAndWeight = FontStyle.Bold;
        rootVisualElement.Add(bottomLabel);

        Label hyperlink = new Label("Quick Start Guide")
        {
            style =
            {
                color = Color.blue,
                unityFontStyleAndWeight = FontStyle.Italic
            }
        };
        hyperlink.RegisterCallback<ClickEvent>(ev => OpenQuickStartLink());
        rootVisualElement.Add(hyperlink);
    }

    void AddBulletLabel(VisualElement container, string labelName, string labelText, int indentCount = 0)
    {
        var row = new VisualElement();
        row.style.flexDirection = FlexDirection.Row;
        row.style.marginBottom = 2;
        row.style.marginLeft = indentCount * 16;

        var bullet = new Label("•")
        {
            style =
            {
                width = 12,
                unityFontStyleAndWeight = FontStyle.Bold,
                marginRight = 4
            }
        };

        var labels = new Label(labelText)
        {
            name = labelName,
            style =
            {
                unityFontStyleAndWeight = FontStyle.Normal,
                whiteSpace = WhiteSpace.Normal,
                flexGrow = 1
            }
        };

        row.Add(bullet);
        row.Add(labels);
        container.Add(row);
    }

    private void OpenQuickStartLink()
    {
        Application.OpenURL("https://git.sam-green.dev/Chromum/UnityImageProcessing_Package/wiki/Guides/QuickStart");
    }
}
